package org.apidesign.apifest08.currency;

      
import java.util.Currency;


/**
 * Thrown when a currency is invalid for a given Convertor.
 * 
 * @author D'Arcy Smith
 * @version 1.0
 */
public class InvalidConversionException
    extends Exception
{
    /**
     * The currency that was tried.
     */
    private final Currency badCurrency;
    
    /**
     * A currency that is valid for the Convertor.
     */
    private final Currency currencyA;

    /**
     * A currency that is valid for the Convertor.
     */
    private final Currency currencyB;
    
    
    /**
     * Construct a new InvalidConversionException with the specified message.
     * 
     * @param msg the message for getMessage.
     * @param bad the currency that is not valid.
     */
    public InvalidConversionException(final String   msg,
                                      final Currency bad)
    {
        this(msg, bad, null, null);
    }

    /**
     * Construct a new InvalidConversionException with the specified message.
     * 
     * @param msg the message for getMessage.
     * @param bad the currency that is not valid.
     * @param a a valid currency.
     * @param b a valid currency.
     */
    public InvalidConversionException(final String   msg,
                                      final Currency bad,
                                      final Currency a,
                                      final Currency b)
    {
        super(msg);

        badCurrency = bad;
        currencyA   = a;
        currencyB   = b;
    }

    /**
     * Get the currency that is not valid.
     * 
     * @return the badCurrency
     */
    public Currency getBadCurrency()
    {
        return (badCurrency);
    }

    /**
     * Get a currency that is valid.
     * 
     * @return the currencyA passed to the constructor.
     */
    public Currency getCurrencyA()
    {
        return (currencyA);
    }

    /**
     * Get a currency that is valid.
     * 
     * @return the currencyB passed to the constructor.
     */
    public Currency getCurrencyB()
    {
        return (currencyB);
    }


}